@@ -14,9 +14,14 @@ PURPLE_NUM = (88,80,192)
 YELLOW = 'rgb(221,213,51)'
 YELLOW_NUM = (221,213,51)
 
+LIME = 'rgb(220, 243, 31)'
+LIME_NUM = (220, 243, 31)
+
 WHITE = 'rgb(255,255,255)'
 WHITE_NUM = (255,255,255)
+
 BLACK = 'rgb(0,0,0)'
+BLACK_NUM = (0,0,0)
 
 GREY = 'rgb(223, 210, 213)'
 GREY_NUM = (192, 196, 199)
