@@ -162,7 +162,7 @@ class Marker(object):
         
         ypos = ydata[self.data_index]
         if self.selected:
-            color = 'y'
+            color = colors.YELLOW_NUM
         else: 
             color = 'w'
             
@@ -283,8 +283,8 @@ class Plot(QtCore.QObject):
         self.freqtrig_lines.blockSignals(True)
         if not self._trig_enable:
             self.freqtrig_lines.setRegion([float(fstart),float(fstop)])
-            self.window.addItem(self.amptrig_line)
             self.window.addItem(self.freqtrig_lines)
+            self.window.addItem(self.amptrig_line)
             self._trig_enable = True
         else:
             self.amptrig_line.setValue(amplitude)
